@@ -63,37 +63,56 @@ def main():
     """Main function with argument parsing"""
     parser = create_argument_parser('HTTPD Server Log Analysis')
     args = parser.parse_args()
-    
-    # SSH 설정 파싱
-    ssh_config = handle_ssh_arguments(args)
-    remote_mode = "ssh" if ssh_config else "local"
-    
-    log_type = "httpd_server"
-    analysis_title = "HTTPD Server Log Analysis"
-    
-    if args.mode == 'realtime':
-        run_generic_realtime_analysis(
-            log_type=log_type,
-            analysis_schema_class=LogAnalysis,
-            prompt_template=get_httpd_server_error_prompt(),
-            analysis_title=analysis_title,
-            chunk_size=args.chunk_size,
-            log_path=args.log_path,
-            only_sampling_mode=args.only_sampling_mode,
-            sampling_threshold=args.sampling_threshold,
-            remote_mode=remote_mode,
-            ssh_config=ssh_config
-        )
-    else:
-        run_generic_batch_analysis(
-            log_type=log_type,
-            analysis_schema_class=LogAnalysis,
-            prompt_template=get_httpd_server_error_prompt(),
-            analysis_title=analysis_title,
-            log_path=args.log_path,
-            remote_mode=remote_mode,
-            ssh_config=ssh_config
-        )
+
+    # 파일 로깅 설정 (콘솔 출력은 기존대로 print 사용)
+    from ..core.commons import setup_logger, LOG_LEVEL
+    logger = setup_logger(__name__, LOG_LEVEL)
+
+    try:
+        # SSH 설정 파싱
+        ssh_config = handle_ssh_arguments(args)
+        remote_mode = "ssh" if ssh_config else "local"
+
+        log_type = "httpd_server"
+        analysis_title = "HTTPD Server Log Analysis"
+
+        logger.info(f"Starting {analysis_title} (mode: {args.mode}, log_path: {args.log_path}, remote_mode: {remote_mode})")
+
+        if args.mode == 'realtime':
+            logger.debug("Running in realtime mode.")
+            run_generic_realtime_analysis(
+                log_type=log_type,
+                analysis_schema_class=LogAnalysis,
+                prompt_template=get_httpd_server_error_prompt(),
+                analysis_title=analysis_title,
+                chunk_size=args.chunk_size,
+                log_path=args.log_path,
+                only_sampling_mode=args.only_sampling_mode,
+                sampling_threshold=args.sampling_threshold,
+                remote_mode=remote_mode,
+                ssh_config=ssh_config
+            )
+            logger.info("Realtime analysis completed.")
+        else:
+            logger.debug("Running in batch mode.")
+            run_generic_batch_analysis(
+                log_type=log_type,
+                analysis_schema_class=LogAnalysis,
+                prompt_template=get_httpd_server_error_prompt(),
+                analysis_title=analysis_title,
+                log_path=args.log_path,
+                remote_mode=remote_mode,
+                ssh_config=ssh_config
+            )
+            logger.info("Batch analysis completed.")
+    except KeyboardInterrupt:
+        logger.info("HTTPD server log analysis interrupted by user")
+        print("\nAnalysis interrupted by user")
+        return 0
+    except Exception as e:
+        logger.exception(f"Unexpected error in HTTPD server log analysis: {e}")
+        print(f"ERROR: Unexpected error: {e}")
+        return 1
 
 
 if __name__ == "__main__":
