@@ -2,12 +2,21 @@
 Configuration module for LogSentinelAI
 Centralizes all configuration constants and environment variable handling
 """
+
 import os
+import logging
 from dotenv import load_dotenv
 
 # .env 파일 로드
 load_dotenv(dotenv_path="config")
 
+# commons.py에서 로깅 설정 가져오기 (순환 참조 해결됨)
+from .commons import setup_logger, LOG_LEVEL
+
+logger = setup_logger(__name__, LOG_LEVEL)
+logger.info("Loading configuration from .env file")
+
+
 # LLM Configuration
 LLM_PROVIDER = os.getenv("LLM_PROVIDER", "openai")
 LLM_MODELS = {
@@ -19,16 +28,25 @@ LLM_MODELS = {
 LLM_API_HOSTS = {
     "ollama": os.getenv("LLM_API_HOST_OLLAMA", "http://127.0.0.1:11434/v1"),
     "vllm": os.getenv("LLM_API_HOST_VLLM", "http://127.0.0.1:5000/v1"),
-    "openai": os.getenv("LLM_API_HOST_OPENAI", "https://api.openai.com/v1")
+    "openai": os.getenv("LLM_API_HOST_OPENAI", "https://api.openai.com/v1"),
+    "gemini": os.getenv("LLM_API_HOST_GEMINI", "https://generativelanguage.googleapis.com/v1beta/openai/")
 }
 LLM_TEMPERATURE = float(os.getenv("LLM_TEMPERATURE", "0.1"))
 LLM_TOP_P = float(os.getenv("LLM_TOP_P", "0.5"))
 LLM_MAX_TOKENS = int(os.getenv("LLM_MAX_TOKENS", "2048"))
 
+
+
+
+# Logging Configuration - managed by commons.py
+# LOG_LEVEL and LOG_FILE are imported from commons
+
+
 # Common Analysis Configuration
 RESPONSE_LANGUAGE = os.getenv("RESPONSE_LANGUAGE", "korean")
 ANALYSIS_MODE = os.getenv("ANALYSIS_MODE", "batch")
 
+
 # Log Paths Configuration - Simple defaults
 LOG_PATHS = {
     "httpd_access": os.getenv("LOG_PATH_HTTPD_ACCESS", "sample-logs/access-10k.log"),
@@ -37,6 +55,7 @@ LOG_PATHS = {
     "general_log": os.getenv("LOG_PATH_GENERAL_LOG", "sample-logs/general.log")
 }
 
+
 # Real-time Monitoring Configuration
 REALTIME_CONFIG = {
     "polling_interval": int(os.getenv("REALTIME_POLLING_INTERVAL", "5")),
@@ -46,6 +65,7 @@ REALTIME_CONFIG = {
     "sampling_threshold": int(os.getenv("REALTIME_SAMPLING_THRESHOLD", "100"))
 }
 
+
 # Default Remote SSH Configuration
 DEFAULT_REMOTE_SSH_CONFIG = {
     "mode": os.getenv("REMOTE_LOG_MODE", "local"),
@@ -57,6 +77,7 @@ DEFAULT_REMOTE_SSH_CONFIG = {
     "timeout": int(os.getenv("REMOTE_SSH_TIMEOUT", "10"))
 }
 
+
 # Default Chunk Sizes
 LOG_CHUNK_SIZES = {
     "httpd_access": int(os.getenv("CHUNK_SIZE_HTTPD_ACCESS", "10")),
@@ -65,6 +86,7 @@ LOG_CHUNK_SIZES = {
     "general_log": int(os.getenv("CHUNK_SIZE_GENERAL_LOG", "10"))
 }
 
+
 # GeoIP Configuration
 GEOIP_CONFIG = {
     "enabled": os.getenv("GEOIP_ENABLED", "true").lower() == "true",
@@ -74,6 +96,7 @@ GEOIP_CONFIG = {
     "include_private_ips": os.getenv("GEOIP_INCLUDE_PRIVATE_IPS", "false").lower() == "true"
 }
 
+
 # Elasticsearch Configuration
 ELASTICSEARCH_HOST = os.getenv("ELASTICSEARCH_HOST", "http://localhost:9200")
 ELASTICSEARCH_USER = os.getenv("ELASTICSEARCH_USER", "elastic")
@@ -96,27 +119,41 @@ def get_analysis_config(log_type, chunk_size=None, analysis_mode=None,
     Returns:
         dict: Configuration containing log_path, chunk_size, response_language, analysis_mode, ssh_config
     """
+    logger.info(f"Getting analysis configuration for log_type: {log_type}")
+    
     mode = analysis_mode if analysis_mode is not None else ANALYSIS_MODE
     access_mode = remote_mode if remote_mode is not None else DEFAULT_REMOTE_SSH_CONFIG["mode"]
     
+    logger.debug(f"Configuration parameters - mode: {mode}, access_mode: {access_mode}")
+    
     # Get log path - use simple LOG_PATHS for all cases
     if access_mode == "ssh":
         log_path = remote_log_path or LOG_PATHS.get(log_type, "")
+        logger.info(f"SSH mode: using log path: {log_path}")
     else:
         log_path = LOG_PATHS.get(log_type, "")
+        logger.info(f"Local mode: using log path: {log_path}")
     
     # SSH configuration
     if access_mode == "ssh":
         final_ssh_config = {**DEFAULT_REMOTE_SSH_CONFIG, **(ssh_config or {}), "mode": "ssh"}
+        logger.info(f"SSH configuration prepared: {final_ssh_config}")
     else:
         final_ssh_config = {"mode": "local"}
+        logger.debug("Local mode configuration prepared")
     
-    return {
+    final_chunk_size = chunk_size if chunk_size is not None else LOG_CHUNK_SIZES.get(log_type, 3)
+    logger.info(f"Final configuration - chunk_size: {final_chunk_size}, response_language: {RESPONSE_LANGUAGE}")
+    
+    config = {
         "log_path": log_path,
-        "chunk_size": chunk_size if chunk_size is not None else LOG_CHUNK_SIZES.get(log_type, 3),
+        "chunk_size": final_chunk_size,
         "response_language": RESPONSE_LANGUAGE,
         "analysis_mode": mode,
         "access_mode": access_mode,
         "ssh_config": final_ssh_config,
         "realtime_config": REALTIME_CONFIG if mode == "realtime" else None
-    }
\ No newline at end of file
+    }
+    
+    logger.info("Analysis configuration prepared successfully")
+    return config
\ No newline at end of file
